@@ -1,6 +1,5 @@
 # coding: utf-8
 
-from __future__ import division, print_function, unicode_literals, absolute_import
 
 """
 This module defines the database classes.
@@ -21,8 +20,9 @@ logger = get_logger(__name__)
 class LammpsCalcDb(CalcDb):
 
     def __init__(self, host="localhost", port=27017, database="lammps", collection="tasks",
-                 user=None, password=None):
-        super(LammpsCalcDb, self).__init__(host, port, database, collection, user, password)
+                 user=None, password=None, **kwargs):
+        super(LammpsCalcDb, self).__init__(host, port, database, collection,
+                                           user, password, **kwargs)
 
     def build_indexes(self, indexes=None, background=True):
         indexes = indexes or []
