@@ -1,4 +1,4 @@
-__author__ = 'Anubhav Jain <ajain@lbl.gov>'
+__author__ = "Anubhav Jain <ajain@lbl.gov>"
 
 # TODO: @computron should be able to load from YAML -computron
 
@@ -12,6 +12,7 @@ VASP_CMD = ">>vasp_cmd<<"
 VDW_KERNEL_DIR = ">>vdw_kernel_dir<<"
 DB_FILE = ">>db_file<<"
 ADD_WF_METADATA = True
+LOBSTER_CMD = ">>lobster_cmd<<"
 
 # whether to use only half the kpoint density in
 # the initial relaxation of a structure optimization for faster performance
@@ -20,10 +21,6 @@ HALF_KPOINTS_FIRST_RELAX = False
 # maximum force allowed on atom for successful structure optimization
 RELAX_MAX_FORCE = 0.25
 
-# Remove Wavecar after the calculation is finished.
-# Only used for SCAN structure optimizations right now.
-REMOVE_WAVECAR = False
-
 # this is a three-way toggle on what to do if your job looks OK,
 # but is actually unconverged (either electronic or ionic).
 # True -> mark job as COMPLETED, but defuse children.
@@ -35,8 +32,42 @@ DEFUSE_UNSUCCESSFUL = "fizzle"
 CUSTODIAN_MAX_ERRORS = 5
 
 # store data from these files in database if present
-STORE_VOLUMETRIC_DATA = ("chgcar", "aeccar0", "aeccar2", "elfcar", "locpot")
+STORE_VOLUMETRIC_DATA = ()  # e.g. ("chgcar", "aeccar0", "aeccar2", "elfcar", "locpot")
 
 # ingest any additional JSON data present into database when parsing VASP directories
 # useful for storing duplicate of FW.json
-STORE_ADDITIONAL_JSON = False
\ No newline at end of file
+STORE_ADDITIONAL_JSON = False
+
+# vasp output files that will be copied to lobster run
+VASP_OUTPUT_FILES = [
+    "OUTCAR",
+    "vasprun.xml",
+    "CHG",
+    "CHGCAR",
+    "CONTCAR",
+    "INCAR",
+    "KPOINTS",
+    "POSCAR",
+    "POTCAR",
+    "DOSCAR",
+    "EIGENVAL",
+    "IBZKPT",
+    "OSZICAR",
+    "WAVECAR",
+    "XDATCAR",
+]
+
+# lobster output files
+LOBSTERINPUT_FILES = ["lobsterin"]
+LOBSTEROUTPUT_FILES = [
+    "lobsterout",
+    "CHARGE.lobster",
+    "COHPCAR.lobster",
+    "COOPCAR.lobster",
+    "DOSCAR.lobster",
+    "GROSSPOP.lobster",
+    "ICOHPLIST.lobster",
+    "ICOOPLIST.lobster",
+    "lobster.out",
+    "projectionData.lobster",
+]
